pecos.error\_models.noise\_impl.noise\_tq\_depolarizing\_leakage
================================================================

.. automodule:: pecos.error_models.noise_impl.noise_tq_depolarizing_leakage







   .. rubric:: Functions

   .. autosummary::

      noise_tq_depolarizing_leakage
